Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6719)

Unified Diff: chrome/browser/safe_browsing/permission_reporter.h

Issue 2178213003: Update RequestTrigger to GestureType in permission report (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Resolve nits Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/safe_browsing/permission_reporter.h
diff --git a/chrome/browser/safe_browsing/permission_reporter.h b/chrome/browser/safe_browsing/permission_reporter.h
index 917590bf0e13d9de8a5c14abac37437841f74b9d..abef8f0fdafb6861142f6c7f4cede66c6ff48269 100644
--- a/chrome/browser/safe_browsing/permission_reporter.h
+++ b/chrome/browser/safe_browsing/permission_reporter.h
@@ -10,6 +10,7 @@
#include <unordered_map>
#include "base/time/time.h"
+#include "chrome/browser/permissions/permission_request.h"
#include "chrome/browser/permissions/permission_uma_util.h"
#include "url/gurl.h"
@@ -50,15 +51,15 @@ class PermissionReporter {
// Sends a serialized permission report to the report collection server.
// The permission report includes |origin| as the origin of
// the site requesting permission, |permission| as the type of permission
// requested, |action| as the action taken, and |user_gesture| in the list of
// request triggers if the action occurred after a user gesture. The report
// will be serialized using protobuf defined in
// //src/chrome/common/safe_browsing/permission_report.proto
void SendReport(const GURL& origin,
content::PermissionType permission,
PermissionAction action,
PermissionSourceUI source_ui,
- bool user_gesture);
+ PermissionRequestGestureType gesture_type);
private:
friend class PermissionReporterTest;
@@ -77,7 +78,7 @@ class PermissionReporter {
content::PermissionType permission,
PermissionAction action,
PermissionSourceUI source_ui,
- bool user_gesture,
+ PermissionRequestGestureType gesture_type,
std::string* output);
// Returns false if the number of reports sent in the last one minute per
« no previous file with comments | « chrome/browser/permissions/permission_uma_util.cc ('k') | chrome/browser/safe_browsing/permission_reporter.cc » ('j') | no next file with comments »
@@ -50,15 +51,15 @@ class PermissionReporter {
// The permission report includes |origin| as the origin of
// the site requesting permission, |permission| as the type of permission
- // requested, |action| as the action taken, and |user_gesture| in the list of
- // request triggers if the action occurred after a user gesture. The report
- // will be serialized using protobuf defined in
+ // requested, |action| as the action taken, and |gesture_type| as to whether
+ // the action occurred after a user gesture. The report will be serialized
+ // using protobuf defined in
// //src/chrome/common/safe_browsing/permission_report.proto
void SendReport(const GURL& origin,

Powered by Google App Engine
This is Rietveld 408576698